exceptiontools.ImpreciseTempoError
==================================

.. abjad-lineage:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError

.. autoclass:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError.__unicode__
   :noindex:
